"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const lodash = require("lodash");
const cli_framework_1 = require("@ionic/cli-framework");
const format_1 = require("@ionic/cli-framework/utils/format");
const cli_utils_1 = require("@ionic/cli-utils");
const command_1 = require("@ionic/cli-utils/lib/command");
const errors_1 = require("@ionic/cli-utils/lib/errors");
class ConfigUnsetCommand extends command_1.Command {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'unset',
                type: 'global',
                summary: 'Delete config values',
                description: `
By default, this command deletes properties in your project's ${chalk_1.default.bold(cli_utils_1.PROJECT_FILE)} file.

For ${chalk_1.default.green('--global')} config, the CLI deletes properties in the global CLI config file (${chalk_1.default.bold('~/.ionic/config.json')}).

For nested properties, separate nest levels with dots. For example, the property name ${chalk_1.default.green('user.email')} will look in the ${chalk_1.default.bold('user')} object (a root-level field in the global CLI config file) for the ${chalk_1.default.bold('email')} field.
      `,
                inputs: [
                    {
                        name: 'property',
                        summary: 'The property name you wish to delete',
                        validators: [cli_framework_1.validators.required],
                    },
                ],
                options: [
                    {
                        name: 'global',
                        summary: 'Use global CLI config',
                        type: Boolean,
                        aliases: ['g'],
                    },
                ],
                exampleCommands: ['', 'type', '--global git.setup', '-g interactive'],
            };
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const [p] = inputs;
            const { global } = options;
            if (!global && !this.env.project.directory) {
                throw new errors_1.FatalException(`Sorry--this won't work outside an Ionic project directory. Did you mean to print global config using ${chalk_1.default.green('--global')}?`);
            }
            const file = global ? this.env.config : this.env.project;
            const config = yield file.load();
            const propertyExists = lodash.has(config, p);
            if (propertyExists) {
                lodash.unset(config, p);
                this.env.log.ok(`${chalk_1.default.green(p)} unset in ${chalk_1.default.bold(format_1.prettyPath(file.filePath))}.`);
            }
            else {
                this.env.log.warn(`Property ${chalk_1.default.green(p)} does not exist--cannot unset.`);
            }
            yield file.save();
        });
    }
}
exports.ConfigUnsetCommand = ConfigUnsetCommand;
