"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const cli_utils_1 = require("@ionic/cli-utils");
const command_1 = require("@ionic/cli-utils/lib/command");
const http_1 = require("@ionic/cli-utils/lib/utils/http");
const serve_1 = require("@ionic/cli-utils/lib/serve");
class DocsCommand extends command_1.Command {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'docs',
                type: 'global',
                summary: 'Open the Ionic documentation website',
                options: [
                    {
                        name: 'browser',
                        summary: `Specifies the browser to use (${serve_1.BROWSERS.map(b => chalk_1.default.green(b)).join(', ')})`,
                        aliases: ['w'],
                        groups: [cli_utils_1.OptionGroup.Advanced],
                    },
                ],
            };
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const opn = yield Promise.resolve().then(() => require('opn'));
            const browser = options['browser'] ? String(options['browser']) : undefined;
            const config = yield this.env.config.load();
            const url = yield this.env.project.getDocsUrl();
            try {
                const { req } = yield http_1.createRequest('HEAD', url, config);
                yield req;
            }
            catch (e) {
                if (cli_utils_1.isSuperAgentError(e) && e.response.status === 404) {
                    this.env.log.warn(`Docs not found for your specific version of Ionic. Directing you to docs homepage.`);
                    opn('https://ionicframework.com/docs', { app: browser, wait: false });
                    return;
                }
                throw e;
            }
            yield opn(url, { app: browser, wait: false });
            this.env.log.ok('Launched Ionic docs in your browser!');
        });
    }
}
exports.DocsCommand = DocsCommand;
