"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const cli_utils_1 = require("@ionic/cli-utils");
const command_1 = require("@ionic/cli-utils/lib/command");
class HelpCommand extends command_1.Command {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'help',
                type: 'global',
                summary: 'Provides help for a certain command',
                exampleCommands: ['start'],
                inputs: [
                    {
                        name: 'command',
                        summary: 'The command you desire help with',
                    },
                ],
                groups: [cli_utils_1.CommandGroup.Hidden],
            };
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { CommandHelpFormatter, NamespaceHelpFormatter } = yield Promise.resolve().then(() => require('@ionic/cli-utils/lib/help'));
            const location = yield this.namespace.locate(inputs);
            if (cli_utils_1.isCommand(location.obj)) {
                const formatter = new CommandHelpFormatter({ location, command: location.obj });
                this.env.log.rawmsg(yield formatter.format());
            }
            else {
                if (location.args.length > 0) {
                    this.env.log.error(`Unable to find command: ${chalk_1.default.green(inputs.join(' '))}` +
                        (this.env.project.directory ? '' : '\nYou may need to be in an Ionic project directory.'));
                }
                const isLoggedIn = yield this.env.session.isLoggedIn();
                const now = new Date();
                const prefix = isLoggedIn ? chalk_1.default.blue('PRO') + ' ' : '';
                const version = this.env.ctx.version;
                const suffix = now.getMonth() === 9 && now.getDate() === 31 ? ' 🎃' : '';
                const formatter = new NamespaceHelpFormatter({
                    inProject: this.env.project.directory ? true : false,
                    version: prefix + version + suffix,
                    location,
                    namespace: location.obj,
                });
                this.env.log.rawmsg(yield formatter.format());
            }
        });
    }
}
exports.HelpCommand = HelpCommand;
