"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = require("path");
const chalk_1 = require("chalk");
const cli_framework_1 = require("@ionic/cli-framework");
const errors_1 = require("@ionic/cli-framework/lib/errors");
const cli_utils_1 = require("@ionic/cli-utils");
const command_1 = require("@ionic/cli-utils/lib/command");
const errors_2 = require("@ionic/cli-utils/lib/errors");
const integrations_1 = require("@ionic/cli-utils/lib/integrations");
class IntegrationsEnableCommand extends command_1.Command {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'enable',
                type: 'project',
                summary: 'Add various integrations to your app',
                inputs: [
                    {
                        name: 'name',
                        summary: `The integration to enable (${integrations_1.INTEGRATION_NAMES.map(i => chalk_1.default.green(i)).join(', ')})`,
                        validators: [cli_framework_1.validators.required, cli_framework_1.contains(integrations_1.INTEGRATION_NAMES, {})],
                    },
                ],
                options: [
                    {
                        name: 'quiet',
                        summary: 'Do not log file operations',
                        type: Boolean,
                    },
                ],
            };
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const [name] = inputs;
            const { quiet } = options;
            if (!cli_utils_1.isIntegrationName(name)) {
                throw new errors_2.FatalException(`Don't know about ${chalk_1.default.green(name)} integration!`);
            }
            const integration = yield integrations_1.BaseIntegration.createFromName(this.env, name);
            const integrationConfig = yield integration.getConfig();
            try {
                if (integrationConfig) {
                    const wasEnabled = integrationConfig.enabled !== false;
                    // We still need to run this whenever this command is run to make sure
                    // everything is good with the integration.
                    yield integration.enable();
                    if (wasEnabled) {
                        this.env.log.info(`Integration ${chalk_1.default.green(integration.name)} enabled.`);
                    }
                    else {
                        this.env.log.ok(`Integration ${chalk_1.default.green(integration.name)} enabled!`);
                    }
                }
                else {
                    yield integration.add({
                        conflictHandler: (f, stats) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                            const isDirectory = stats.isDirectory();
                            const filename = `${path.basename(f)}${isDirectory ? '/' : ''}`;
                            const type = isDirectory ? 'directory' : 'file';
                            const confirm = yield this.env.prompt({
                                type: 'confirm',
                                name: 'confirm',
                                message: `The ${chalk_1.default.cyan(filename)} ${type} exists in project. Overwrite?`,
                                default: false,
                            });
                            return confirm;
                        }),
                        onFileCreate: f => {
                            if (!quiet) {
                                this.env.log.msg(`  ${chalk_1.default.green('create')} ${f}`);
                            }
                        },
                    });
                    this.env.log.ok(`Integration ${chalk_1.default.green(integration.name)} added!`);
                }
            }
            catch (e) {
                if (e instanceof errors_1.BaseError) {
                    throw new errors_2.FatalException(e.message);
                }
                throw e;
            }
            yield this.env.project.save();
        });
    }
}
exports.IntegrationsEnableCommand = IntegrationsEnableCommand;
